@@ -23,14 +23,11 @@
 
 #include <QSortFilterProxyModel>
 
-namespace KCalendarCore
-{
+namespace KCalendarCore {
 class CalFilter;
 }
 
-namespace Akonadi
-{
-
+namespace Akonadi {
 class CalFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -48,7 +45,6 @@ private:
     class Private;
     Private *const d;
 };
-
 }
 
 #endif
