@@ -39,7 +39,6 @@ using namespace KCalendarCore;
 
 AKONADI_CALENDAR_TESTS_EXPORT bool akonadi_calendar_running_unittests = false;
 
-
 static ITIPHandlerDialogDelegate::Action actionFromStatus(ITIPHandlerHelper::SendResult result)
 {
     //enum SendResult {
@@ -73,17 +72,12 @@ static bool allowedModificationsWithoutRevisionUpdate(const Incidence::Ptr &inci
     const QSet<KCalendarCore::IncidenceBase::Field> dirtyFields = incidence->dirtyFields();
     QSet<KCalendarCore::IncidenceBase::Field> alarmOnlyModify;
     alarmOnlyModify << IncidenceBase::FieldAlarms << IncidenceBase::FieldLastModified;
-    return (dirtyFields == alarmOnlyModify);
+    return dirtyFields == alarmOnlyModify;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 // Does a queued emit, with QMetaObject::invokeMethod
-static void emitCreateFinished(IncidenceChanger *changer,
-                               int changeId,
-                               const Akonadi::Item &item,
-                               Akonadi::IncidenceChanger::ResultCode resultCode,
-                               const QString &errorString)
+static void emitCreateFinished(IncidenceChanger *changer, int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString)
 {
     QMetaObject::invokeMethod(changer, "createFinished", Qt::QueuedConnection,
                               Q_ARG(int, changeId),
@@ -93,11 +87,7 @@ static void emitCreateFinished(IncidenceChanger *changer,
 }
 
 // Does a queued emit, with QMetaObject::invokeMethod
-static void emitModifyFinished(IncidenceChanger *changer,
-                               int changeId,
-                               const Akonadi::Item &item,
-                               IncidenceChanger::ResultCode resultCode,
-                               const QString &errorString)
+static void emitModifyFinished(IncidenceChanger *changer, int changeId, const Akonadi::Item &item, IncidenceChanger::ResultCode resultCode, const QString &errorString)
 {
     QMetaObject::invokeMethod(changer, "modifyFinished", Qt::QueuedConnection,
                               Q_ARG(int, changeId),
@@ -107,11 +97,7 @@ static void emitModifyFinished(IncidenceChanger *changer,
 }
 
 // Does a queued emit, with QMetaObject::invokeMethod
-static void emitDeleteFinished(IncidenceChanger *changer,
-                               int changeId,
-                               const QVector<Akonadi::Item::Id> &itemIdList,
-                               IncidenceChanger::ResultCode resultCode,
-                               const QString &errorString)
+static void emitDeleteFinished(IncidenceChanger *changer, int changeId, const QVector<Akonadi::Item::Id> &itemIdList, IncidenceChanger::ResultCode resultCode, const QString &errorString)
 {
     QMetaObject::invokeMethod(changer, "deleteFinished", Qt::QueuedConnection,
                               Q_ARG(int, changeId),
@@ -151,23 +137,22 @@ IncidenceChanger::Private::Private(bool enableHistory, ITIPHandlerComponentFacto
 
 IncidenceChanger::Private::~Private()
 {
-    if (!mAtomicOperations.isEmpty() ||
-            !mQueuedModifications.isEmpty() ||
-            !mModificationsInProgress.isEmpty()) {
+    if (!mAtomicOperations.isEmpty()
+        || !mQueuedModifications.isEmpty()
+        || !mModificationsInProgress.isEmpty()) {
         qCDebug(AKONADICALENDAR_LOG) << "Normal if the application was being used. "
-                                     "But might indicate a memory leak if it wasn't";
+                                        "But might indicate a memory leak if it wasn't";
     }
 }
 
 bool IncidenceChanger::Private::atomicOperationIsValid(uint atomicOperationId) const
 {
     // Changes must be done between startAtomicOperation() and endAtomicOperation()
-    return mAtomicOperations.contains(atomicOperationId) &&
-           !mAtomicOperations[atomicOperationId]->m_endCalled;
+    return mAtomicOperations.contains(atomicOperationId)
+           && !mAtomicOperations[atomicOperationId]->m_endCalled;
 }
 
-bool IncidenceChanger::Private::hasRights(const Collection &collection,
-        IncidenceChanger::ChangeType changeType) const
+bool IncidenceChanger::Private::hasRights(const Collection &collection, IncidenceChanger::ChangeType changeType) const
 {
     bool result = false;
     switch (changeType) {
@@ -189,8 +174,8 @@ bool IncidenceChanger::Private::hasRights(const Collection &collection,
 
 Akonadi::Job *IncidenceChanger::Private::parentJob(const Change::Ptr &change) const
 {
-    return (mBatchOperationInProgress && !change->queuedModification) ?
-           mAtomicOperations[mLatestAtomicOperationId]->transaction()
+    return (mBatchOperationInProgress && !change->queuedModification)
+           ? mAtomicOperations[mLatestAtomicOperationId]->transaction()
            : nullptr;
 }
 
@@ -203,7 +188,7 @@ void IncidenceChanger::Private::queueModification(const Change::Ptr &change)
     if (mQueuedModifications.contains(id)) {
         Change::Ptr toBeDiscarded = mQueuedModifications.take(id);
         toBeDiscarded->resultCode = ResultCodeModificationDiscarded;
-        toBeDiscarded->completed  = true;
+        toBeDiscarded->completed = true;
         mChangeById.remove(toBeDiscarded->id);
     }
 
@@ -272,7 +257,7 @@ void IncidenceChanger::Private::handleCreateJobResult(KJob *job)
         }
         mChangeById.remove(change->id);
         change->errorString = errorString;
-        change->resultCode  = resultCode;
+        change->resultCode = resultCode;
         // puff, change finally goes out of scope, and emits the incidenceCreated signal.
     } else {
         Q_ASSERT(item.isValid());
@@ -319,7 +304,7 @@ void IncidenceChanger::Private::handleCreateJobResult2(int changeId, ITIPHandler
     }
 
     change->errorString = QString();
-    change->resultCode  = ResultCodeSuccess;
+    change->resultCode = ResultCodeSuccess;
     // puff, change finally goes out of scope, and emits the incidenceCreated signal.
 }
 
@@ -361,7 +346,6 @@ void IncidenceChanger::Private::handleDeleteJobResult(KJob *job)
         change->resultCode = ResultCodeJobError;
         change->errorString = errorString;
         change->emitCompletionSignal();
-
     } else { // success
         if (change->recordToHistory) {
             Q_ASSERT(mHistory);
@@ -378,14 +362,14 @@ void IncidenceChanger::Private::handleDeleteJobResult(KJob *job)
     }
 }
 
-void  IncidenceChanger::Private::handleDeleteJobResult2(int changeId, ITIPHandlerHelper::SendResult status)
+void IncidenceChanger::Private::handleDeleteJobResult2(int changeId, ITIPHandlerHelper::SendResult status)
 {
     Change::Ptr change = mChangeById[changeId];
     mChangeById.remove(change->id);
 
     if (status == ITIPHandlerHelper::ResultSuccess) {
         change->errorString = QString();
-        change->resultCode  = ResultCodeSuccess;
+        change->resultCode = ResultCodeSuccess;
     } else {
         change->errorString = i18nc("errormessage for a job ended with an unexpected result", "An unknown error occurred");
         change->resultCode = ResultCodeJobError;
@@ -430,15 +414,13 @@ void IncidenceChanger::Private::handleModifyJobResult(KJob *job)
         }
         mChangeById.remove(change->id);
         change->errorString = errorString;
-        change->resultCode  = resultCode;
+        change->resultCode = resultCode;
         // puff, change finally goes out of scope, and emits the incidenceModified signal.
 
         QMetaObject::invokeMethod(this, "performNextModification",
                                   Qt::QueuedConnection,
                                   Q_ARG(Akonadi::Item::Id, item.id()));
-
     } else { // success
-
         (*(s_latestRevisionByItemId()))[item.id()] = item.revision();
         change->newItem = item;
         if (change->recordToHistory && !change->originalItems.isEmpty()) {
@@ -466,7 +448,7 @@ void IncidenceChanger::Private::handleModifyJobResult2(int changeId, ITIPHandler
         mInvitationStatusByAtomicOperation.insert(change->atomicOperationId, status);
     }
     change->errorString = QString();
-    change->resultCode  = ResultCodeSuccess;
+    change->resultCode = ResultCodeSuccess;
     // puff, change finally goes out of scope, and emits the incidenceModified signal.
 
     QMetaObject::invokeMethod(this, "performNextModification",
@@ -487,7 +469,8 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
         case IncidenceChanger::ChangeTypeCreate:
             // nothing needs to be done
             break;
-        case IncidenceChanger::ChangeTypeDelete: {
+        case IncidenceChanger::ChangeTypeDelete:
+        {
             ITIPHandlerHelper::SendResult status;
             bool sendOk = true;
             Q_ASSERT(!change->originalItems.isEmpty());
@@ -530,7 +513,8 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
             }
             return;
         }
-        case IncidenceChanger::ChangeTypeModify: {
+        case IncidenceChanger::ChangeTypeModify:
+        {
             if (change->originalItems.isEmpty()) {
                 break;
             }
@@ -605,7 +589,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
         }
 
         switch (change->type) {
-        case IncidenceChanger::ChangeTypeCreate: {
+        case IncidenceChanger::ChangeTypeCreate:
+        {
             Incidence::Ptr incidence = CalendarUtils::incidence(change->newItem);
             if (incidence->supportsGroupwareCommunication()) {
                 handler->sendIncidenceCreatedMessage(KCalendarCore::iTIPRequest, incidence);
@@ -613,7 +598,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             }
             break;
         }
-        case IncidenceChanger::ChangeTypeDelete: {
+        case IncidenceChanger::ChangeTypeDelete:
             handler->deleteLater();
             handler = nullptr;
             Q_ASSERT(!change->originalItems.isEmpty());
@@ -630,8 +615,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
                     bool notifyOrganizer = false;
                     const KCalendarCore::Attendee me(incidence->attendeeByMails(myEmails));
                     if (!me.isNull()) {
-                        if (me.status() == KCalendarCore::Attendee::Accepted ||
-                                me.status() == KCalendarCore::Attendee::Delegated) {
+                        if (me.status() == KCalendarCore::Attendee::Accepted
+                            || me.status() == KCalendarCore::Attendee::Delegated) {
                             notifyOrganizer = true;
                         }
                         KCalendarCore::Attendee newMe(me);
@@ -648,8 +633,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
                 }
             }
             break;
-        }
-        case IncidenceChanger::ChangeTypeModify: {
+        case IncidenceChanger::ChangeTypeModify:
+        {
             if (change->originalItems.isEmpty()) {
                 break;
             }
@@ -658,8 +643,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             Incidence::Ptr oldIncidence = CalendarUtils::incidence(change->originalItems.first());
             Incidence::Ptr newIncidence = CalendarUtils::incidence(change->newItem);
 
-            if (!newIncidence->supportsGroupwareCommunication() ||
-                    !Akonadi::CalendarUtils::thatIsMe(newIncidence->organizer().email())) {
+            if (!newIncidence->supportsGroupwareCommunication()
+                || !Akonadi::CalendarUtils::thatIsMe(newIncidence->organizer().email())) {
                 // If we're not the organizer, the user already saw the "Do you really want to do this, incidence will become out of sync"
                 break;
             }
@@ -673,8 +658,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             }
 
             const bool attendeeStatusChanged = myAttendeeStatusChanged(newIncidence,
-                                               oldIncidence,
-                                               Akonadi::CalendarUtils::allEmails());
+                                                                       oldIncidence,
+                                                                       Akonadi::CalendarUtils::allEmails());
 
             handler->sendIncidenceModifiedMessage(KCalendarCore::iTIPRequest, newIncidence, attendeeStatusChanged);
             return;
@@ -687,7 +672,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             return;
         }
         handler->deleteLater();
-        handler  = nullptr;
+        handler = nullptr;
         change->emitUserDialogClosedAfterChange(ITIPHandlerHelper::ResultSuccess);
     } else {
         change->emitUserDialogClosedAfterChange(ITIPHandlerHelper::ResultSuccess);
@@ -695,9 +680,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
 }
 
 /** static */
-bool IncidenceChanger::Private::myAttendeeStatusChanged(const Incidence::Ptr &newInc,
-        const Incidence::Ptr &oldInc,
-        const QStringList &myEmails)
+bool IncidenceChanger::Private::myAttendeeStatusChanged(const Incidence::Ptr &newInc, const Incidence::Ptr &oldInc, const QStringList &myEmails)
 {
     Q_ASSERT(newInc);
     Q_ASSERT(oldInc);
@@ -709,19 +692,19 @@ bool IncidenceChanger::Private::myAttendeeStatusChanged(const Incidence::Ptr &ne
 
 IncidenceChanger::IncidenceChanger(QObject *parent)
     : QObject(parent)
-    , d(new Private(/**history=*/true, /*factory=*/nullptr, this))
+    , d(new Private(/**history=*/ true, /*factory=*/ nullptr, this))
 {
 }
 
 IncidenceChanger::IncidenceChanger(ITIPHandlerComponentFactory *factory, QObject *parent)
     : QObject(parent)
-    , d(new Private(/**history=*/true, factory, this))
+    , d(new Private(/**history=*/ true, factory, this))
 {
 }
 
 IncidenceChanger::IncidenceChanger(bool enableHistory, QObject *parent)
     : QObject(parent)
-    , d(new Private(enableHistory, /*factory=*/nullptr, this))
+    , d(new Private(enableHistory, /*factory=*/ nullptr, this))
 {
 }
 
@@ -730,9 +713,7 @@ IncidenceChanger::~IncidenceChanger()
     delete d;
 }
 
-int IncidenceChanger::createIncidence(const Incidence::Ptr &incidence,
-                                      const Collection &collection,
-                                      QWidget *parent)
+int IncidenceChanger::createIncidence(const Incidence::Ptr &incidence, const Collection &collection, QWidget *parent)
 {
     if (!incidence) {
         qCWarning(AKONADICALENDAR_LOG) << "An invalid payload is not allowed.";
@@ -743,7 +724,7 @@ int IncidenceChanger::createIncidence(const Incidence::Ptr &incidence,
     const uint atomicOperationId = d->mBatchOperationInProgress ? d->mLatestAtomicOperationId : 0;
 
     const Change::Ptr change(new CreationChange(this, ++d->mLatestChangeId,
-                             atomicOperationId, parent));
+                                                atomicOperationId, parent));
     const int changeId = change->id;
     Q_ASSERT(!(d->mBatchOperationInProgress && !d->mAtomicOperations.contains(atomicOperationId)));
     if (d->mBatchOperationInProgress && d->mAtomicOperations[atomicOperationId]->rolledback()) {
@@ -838,8 +819,8 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
         QVector<Akonadi::Item::Id> itemIdList;
         itemIdList.append(Item().id());
         qCDebug(AKONADICALENDAR_LOG) << "Items already deleted or being deleted, skipping";
-        const QString errorMessage =
-            i18n("That calendar item was already deleted, or currently being deleted.");
+        const QString errorMessage
+            = i18n("That calendar item was already deleted, or currently being deleted.");
         // Queued emit because return must be executed first, otherwise caller won't know this workId
         change->resultCode = ResultCodeAlreadyDeleted;
         change->errorString = errorMessage;
@@ -890,9 +871,7 @@ void IncidenceChanger::Private::deleteIncidences2(int changeId, ITIPHandlerHelpe
             this, &Private::handleDeleteJobResult, Qt::QueuedConnection);
 }
 
-int IncidenceChanger::modifyIncidence(const Item &changedItem,
-                                      const KCalendarCore::Incidence::Ptr &originalPayload,
-                                      QWidget *parent)
+int IncidenceChanger::modifyIncidence(const Item &changedItem, const KCalendarCore::Incidence::Ptr &originalPayload, QWidget *parent)
 {
     if (!changedItem.isValid() || !changedItem.hasPayload<Incidence::Ptr>()) {
         qCWarning(AKONADICALENDAR_LOG) << "An invalid item or payload is not allowed.";
@@ -915,7 +894,7 @@ int IncidenceChanger::modifyIncidence(const Item &changedItem,
     const uint atomicOperationId = d->mBatchOperationInProgress ? d->mLatestAtomicOperationId : 0;
     const int changeId = ++d->mLatestChangeId;
     ModificationChange *modificationChange = new ModificationChange(this, changeId,
-            atomicOperationId, parent);
+                                                                    atomicOperationId, parent);
     Change::Ptr change(modificationChange);
 
     if (originalPayload) {
@@ -971,8 +950,8 @@ void IncidenceChanger::Private::performModification(const Change::Ptr &change)
 
     const uint atomicOperationId = change->atomicOperationId;
     const bool hasAtomicOperationId = atomicOperationId != 0;
-    if (hasAtomicOperationId &&
-            mAtomicOperations[atomicOperationId]->rolledback()) {
+    if (hasAtomicOperationId
+        && mAtomicOperations[atomicOperationId]->rolledback()) {
         const QString errorMessage = showErrorDialog(ResultCodeRolledback, nullptr);
         qCritical() << errorMessage;
         emitModifyFinished(q, changeId, newItem, ResultCodeRolledback, errorMessage);
@@ -983,13 +962,13 @@ void IncidenceChanger::Private::performModification(const Change::Ptr &change)
                 this, &Private::performModification2);
         handleInvitationsBeforeChange(change);
     } else {
-        performModification2(change->id,  ITIPHandlerHelper::ResultSuccess);
+        performModification2(change->id, ITIPHandlerHelper::ResultSuccess);
     }
 }
 
 void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHelper::SendResult status)
 {
-    Change::Ptr change  =  mChangeById[changeId];
+    Change::Ptr change = mChangeById[changeId];
     const Item::Id id = change->newItem.id();
     Akonadi::Item &newItem = change->newItem;
     Q_ASSERT(newItem.isValid());
@@ -1005,8 +984,8 @@ void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHe
     const bool hasAtomicOperationId = atomicOperationId != 0;
 
     QHash<Akonadi::Item::Id, int> &latestRevisionByItemId = *(s_latestRevisionByItemId());
-    if (latestRevisionByItemId.contains(id) &&
-            latestRevisionByItemId[id] > newItem.revision()) {
+    if (latestRevisionByItemId.contains(id)
+        && latestRevisionByItemId[id] > newItem.revision()) {
         /* When a ItemModifyJob ends, the application can still modify the old items if the user
          * is quick because the ETM wasn't updated yet, and we'll get a STORE error, because
          * we are not modifying the latest revision.
@@ -1036,8 +1015,8 @@ void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHe
         if (!(incidence->dirtyFields() & resetPartStatus).isEmpty() && weAreOrganizer(incidence)) {
             auto attendees = incidence->attendees();
             for (auto &attendee : attendees) {
-                if (attendee.role() != Attendee::NonParticipant &&
-                        attendee.status() != Attendee::Delegated && !Akonadi::CalendarUtils::thatIsMe(attendee)) {
+                if (attendee.role() != Attendee::NonParticipant
+                    && attendee.status() != Attendee::Delegated && !Akonadi::CalendarUtils::thatIsMe(attendee)) {
                     attendee.setStatus(Attendee::NeedsAction);
                     attendee.setRSVP(true);
                 }
@@ -1105,8 +1084,8 @@ void IncidenceChanger::endAtomicOperation()
 
     const bool allJobsCompleted = !atomicOperation->pendingJobs();
 
-    if (allJobsCompleted && atomicOperation->rolledback() &&
-            atomicOperation->m_transactionCompleted) {
+    if (allJobsCompleted && atomicOperation->rolledback()
+        && atomicOperation->m_transactionCompleted) {
         // The transaction job already completed, we can cleanup:
         delete d->mAtomicOperations.take(d->mLatestAtomicOperationId);
         d->mBatchOperationInProgress = false;
@@ -1219,8 +1198,7 @@ Akonadi::Collection IncidenceChanger::lastCollectionUsed() const
     return d->mLastCollectionUsed;
 }
 
-QString IncidenceChanger::Private::showErrorDialog(IncidenceChanger::ResultCode resultCode,
-        QWidget *parent)
+QString IncidenceChanger::Private::showErrorDialog(IncidenceChanger::ResultCode resultCode, QWidget *parent)
 {
     QString errorString;
     switch (resultCode) {
@@ -1253,11 +1231,10 @@ QString IncidenceChanger::Private::showErrorDialog(IncidenceChanger::ResultCode
     return errorString;
 }
 
-void IncidenceChanger::Private::adjustRecurrence(const KCalendarCore::Incidence::Ptr &originalIncidence,
-        const KCalendarCore::Incidence::Ptr &incidence)
+void IncidenceChanger::Private::adjustRecurrence(const KCalendarCore::Incidence::Ptr &originalIncidence, const KCalendarCore::Incidence::Ptr &incidence)
 {
     if (!originalIncidence || !incidence->recurs() || incidence->hasRecurrenceId() || !mAutoAdjustRecurrence
-            || !incidence->dirtyFields().contains(KCalendarCore::Incidence::FieldDtStart)) {
+        || !incidence->dirtyFields().contains(KCalendarCore::Incidence::FieldDtStart)) {
         return;
     }
 
@@ -1270,7 +1247,8 @@ void IncidenceChanger::Private::adjustRecurrence(const KCalendarCore::Incidence:
 
     KCalendarCore::Recurrence *recurrence = incidence->recurrence();
     switch (recurrence->recurrenceType()) {
-    case KCalendarCore::Recurrence::rWeekly: {
+    case KCalendarCore::Recurrence::rWeekly:
+    {
         QBitArray days = recurrence->days();
         const int oldIndex = originalDate.dayOfWeek() - 1; // QDate returns [1-7];
         const int newIndex = newStartDate.dayOfWeek() - 1;
@@ -1313,8 +1291,7 @@ void IncidenceChanger::Private::cleanupTransaction()
     }
 }
 
-bool IncidenceChanger::Private::allowAtomicOperation(int atomicOperationId,
-        const Change::Ptr &change) const
+bool IncidenceChanger::Private::allowAtomicOperation(int atomicOperationId, const Change::Ptr &change) const
 {
     bool allow = true;
     if (atomicOperationId > 0) {
@@ -1395,8 +1372,7 @@ void IncidenceChanger::cancelAttendees( const Akonadi::Item &aitem )
 
 */
 
-AtomicOperation::AtomicOperation(IncidenceChanger::Private *icp,
-                                 uint ident)
+AtomicOperation::AtomicOperation(IncidenceChanger::Private *icp, uint ident)
     : m_id(ident)
     , m_endCalled(false)
     , m_numCompletedChanges(0)
@@ -1404,7 +1380,6 @@ AtomicOperation::AtomicOperation(IncidenceChanger::Private *icp,
     , m_wasRolledback(false)
     , m_transaction(nullptr)
     , m_incidenceChangerPrivate(icp)
-
 {
     Q_ASSERT(m_id != 0);
 }
