@@ -24,12 +24,10 @@
 #include "ui_publishdialog_base.h"
 #include <KContacts/Addressee>
 
-namespace Akonadi
-{
-
+namespace Akonadi {
 class Q_DECL_HIDDEN PublishDialog::Private : public QObject
 {
-    Q_OBJECT    
+    Q_OBJECT
 public:
     Private(PublishDialog *q);
     void insertAddresses(const KContacts::Addressee::List &list);
